@@ -28,8 +28,7 @@
 
 class OrgKdeKorganizerCalendarInterface;
 
-namespace KontactInterface
-{
+namespace KontactInterface {
 class UniqueAppWatcher;
 }
 
