@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,8 +30,10 @@ void KOrgMigrateApplication::migrate()
 {
     //Migrate to xdg
     Kdelibs4ConfigMigrator migrate(QStringLiteral("korganizer"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("korganizerrc") << QStringLiteral("freebusyurls"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("korganizer_part.rc") << QStringLiteral("korganizerui.rc"));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("korganizerrc")
+                                         << QStringLiteral("freebusyurls"));
+    migrate.setUiFiles(QStringList() << QStringLiteral("korganizer_part.rc")
+                                     << QStringLiteral("korganizerui.rc"));
     migrate.migrate();
 
     // Migrate folders and files.
@@ -69,4 +71,3 @@ void KOrgMigrateApplication::initializeMigrator()
     //TODO add folder to migrate
     // If you add new MigrateFileInfo we need to increase "currentVersion"  and initialVersion
 }
-
